package menhirLib

  1. Overview
  2. Docs

Module MenhirLibSource

Sourcemodule Convert : sig ... end

This module defines two APIs for parsers, namely the traditional API and the revised API, and offers conversions between these APIs.

Sourcemodule Engine : sig ... end
Sourcemodule EngineTypes : sig ... end

This module defines several types and module types that are used in the specification of the module Engine.

Sourcemodule ErrorReports : sig ... end

This module offers functions that can help produce syntax error messages.

Sourcemodule IncrementalEngine : sig ... end
Sourcemodule InspectionTableFormat : sig ... end
Sourcemodule LexerUtil : sig ... end
Sourcemodule LinearizedArray : sig ... end
Sourcemodule PackedIntArray : sig ... end

This module allows packing an array of (small) integers inside a string, using less than one word of memory per array element.

Sourcemodule Printers : sig ... end
Sourcemodule RowDisplacementDecode : sig ... end

Row displacement aims to compress a two-dimensional table where some values are considered insignificant.

Sourcemodule StaticVersion : sig ... end
Sourcemodule TableFormat : sig ... end
Sourcemodule TableInterpreter : sig ... end